;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'cperl '("cperl-mode"))
(custom-add-loads 'prolog '("prolog"))
(custom-add-loads 'pascal '("pascal"))
(custom-add-loads 'tcl '("tcl"))
(custom-add-loads 'cperl-indentation-details '("cperl-mode"))
(custom-add-loads 'icon '("icon"))
(custom-add-loads 'fortran-indent '("fortran"))
(custom-add-loads 'compilation-remote '("mode-compile"))
(custom-add-loads 'lisp-indent '("cl-indent"))
(custom-add-loads 'tools '("diff-mode" "make-mode" "mode-compile"))
(custom-add-loads 'cperl-speed '("cperl-mode"))
(custom-add-loads 'compile-perl '("mode-compile"))
(custom-add-loads 'diff-mode '("diff-mode"))
(custom-add-loads 'lisp '("cl-indent" "mode-compile"))
(custom-add-loads 'diff '("diff-mode"))
(custom-add-loads 'compile-c '("mode-compile"))
(custom-add-loads 'compilation-frame '("mode-compile"))
(custom-add-loads 'cperl-affected-by-hairy '("cperl-mode"))
(custom-add-loads 'f90 '("f90"))
(custom-add-loads 'compile-sh '("mode-compile"))
(custom-add-loads 'cperl-autoinsert-details '("cperl-mode"))
(custom-add-loads 'asm '("asm-mode"))
(custom-add-loads 'compile-fortran '("mode-compile"))
(custom-add-loads 'fortran-comment '("fortran"))
(custom-add-loads 'frames '("mode-compile"))
(custom-add-loads 'verilog '("verilog-mode"))
(custom-add-loads 'compile-phthon '("mode-compile"))
(custom-add-loads 'compilation-script '("mode-compile"))
(custom-add-loads 'f90-indent '("f90"))
(custom-add-loads 'compilation-elisp '("mode-compile"))
(custom-add-loads 'compilation '("mode-compile"))
(custom-add-loads 'SQL '("sql"))
(custom-add-loads 'makemode '("make-mode"))
(custom-add-loads 'vrml '("vrml-mode"))
(custom-add-loads 'simula '("simula"))
(custom-add-loads 'compile-java '("mode-compile"))
(custom-add-loads 'compile-python '("mode-compile"))
(custom-add-loads 'compile-csh '("mode-compile"))
(custom-add-loads 'fortran '("f90" "fortran"))
(custom-add-loads 'development '("mode-compile"))
(custom-add-loads 'cperl-faces '("cperl-mode"))
(custom-add-loads 'languages '("asm-mode" "cperl-mode" "fortran" "icon" "mode-compile" "pascal" "prolog" "python-mode" "rexx-mode" "simula" "tcl" "verilog-mode" "vrml-mode"))
(custom-add-loads 'compilation-lang '("mode-compile"))
(custom-add-loads 'faces '("make-mode"))
(custom-add-loads 'cperl-help-system '("cperl-mode"))
(custom-add-loads 'compile-zsh '("mode-compile"))
(custom-add-loads 'processes '("sql"))
(custom-add-loads 'rexx '("rexx-mode"))
(custom-add-loads 'compile-ada '("mode-compile"))
(custom-add-loads 'python '("python-mode"))
(custom-add-loads 'compile-c++ '("mode-compile"))
(custom-add-loads 'makefile-mode '("make-mode"))
(custom-add-loads 'compile-tcl '("mode-compile"))
(custom-add-loads 'c '("mode-compile"))

;;; custom-load.el ends here
